=============================
Structurizr for Python
=============================

.. image:: https://img.shields.io/pypi/v/structurizr-python.svg
   :target: https://pypi.org/project/structurizr-python/
   :alt: Current PyPI Version

.. image:: https://img.shields.io/pypi/pyversions/structurizr-python.svg
   :target: https://pypi.org/project/structurizr-python/
   :alt: Supported Python Versions

.. image:: https://img.shields.io/pypi/l/structurizr-python.svg
   :target: https://www.apache.org/licenses/LICENSE-2.0
   :alt: Apache Software License Version 2.0

.. image:: https://img.shields.io/badge/Contributor%20Covenant-v1.4%20adopted-ff69b4.svg
   :target: https://github.com/Midnighter/structurizr-python/blob/master/.github/CODE_OF_CONDUCT.md
   :alt: Code of Conduct

.. image:: https://codecov.io/gh/Midnighter/structurizr-python/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/Midnighter/structurizr-python
   :alt: Codecov

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/ambv/black
   :alt: Black

.. image:: https://readthedocs.org/projects/structurizr-python/badge/?version=latest
   :target: https://structurizr-python.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

.. summary-start

A Python client package for the Structurizr cloud service and on-premises installation.

Warning
=======

The structurizr-python package is in active development and should be considered Alpha
software. Reports of problems are appreciated but please do not expect fully working
software at this point. If you want to get involved, you are most welcome as this is
a spare time project. Please write me an e-mail or on the
`Structurizr Slack team <https://structurizr.com/help>`_ so that we can coordinate.

Install
=======

It's as simple as:

.. code-block:: console

    pip install --pre structurizr-python

Copyright
=========

* Copyright © 2020, Moritz E. Beber.
* Free software distributed under the `Apache Software License 2.0
  <https://www.apache.org/licenses/LICENSE-2.0>`_.

.. summary-end
